@@ -1,5 +1,5 @@
 /**************************************************
-* unit:    struct            release 0.16         *
+* unit:    struct            release 0.19         *
 * purpose: test of functionality of struct lib    *
 ***************************************************/
 #ifdef _MSC_VER
@@ -21,7 +21,7 @@
 #include "struct.h"
 
 char Blob[32];
-char *TEMP_FILE = "temp.tmp";
+const char *TEMP_FILE = "temp.tmp";
 
 void Benchmark(void);
 
@@ -96,7 +96,7 @@ int Ops;
 TopolRasHeader SU;
 
 puts("");
-puts("<<<struct>>> (c)1998-2024 Jaroslav Fojtik");
+puts("<<<struct>>> (c)1998-2025 Jaroslav Fojtik");
 puts("                 This program tests the struct.c library");
 #ifdef LO_ENDIAN
  puts("***LO_ENDIAN defined***");
@@ -110,23 +110,30 @@ puts("                 This program tests the struct.c library");
 #ifdef NATIVE_ACCESS
  puts("***NATIVE access***");
 #endif
+ fflush(stdout);
 
  if(argc>1)
-    {
-    Ops=0;
-    for(i=1; i<argc; i++)
-      {
-      if(!strcmp(argv[i],"-bench")) Ops|=3;
-      if(!strcmp(argv[i],"-demo")) Ops|=4;
-      if(!strcmp(argv[i],"-test")) Ops|=1;
-      if(!strcmp(argv[i],"-pause")) Pause=1;
-      if(!strcmp(argv[i],"-f"))
-        {
-        i++;
-        TEMP_FILE = argv[i];
-        }
-      }
-    }
+ {
+   Ops=0;
+   for(i=1; i<argc; i++)
+   {
+     if(!strcmp(argv[i],"-bench")) Ops|=3;
+     if(!strcmp(argv[i],"-demo")) Ops|=4;
+     if(!strcmp(argv[i],"-test")) Ops|=1;
+     if(!strcmp(argv[i],"-pause")) Pause=1;
+     if(!strcmp(argv[i],"-f"))
+     {
+       i++;
+       TEMP_FILE = argv[i];
+     }
+     if(!strcmp(argv[i],"-help") || !strcmp(argv[i],"/help"))
+     {
+       printf("Command line parameters:\n-bench; -demo; -f tmpfilename; -help; -pause; -test\n");
+       return 1;
+     }
+   }
+   if(Ops==0) Ops=3;
+ }
  else Ops=3;
 
  err = 0;
@@ -134,7 +141,7 @@ puts("                 This program tests the struct.c library");
  {
 
  //////////////////////////////////
- puts(" Testing file operations");
+ puts(" Testing file operations"); fflush(stdout);
 
  TempF = fopen(TEMP_FILE,"wb");
  if(TempF==NULL)
@@ -269,7 +276,7 @@ puts("                 This program tests the struct.c library");
 
 
  //////////////////////////////////
- puts(" Testing struct manipulation");
+ puts(" Testing struct manipulation"); fflush(stdout);
 
  TempF = fopen(TEMP_FILE,"wb");
  if(TempF==NULL)
@@ -417,7 +424,7 @@ if(W2!=0x1234)
 
  //////////////////////////////////
 FileError:
- puts(" Testing memory access macros");
+ puts(" Testing memory access macros"); fflush(stdout);
 
  D = 0x55667788;
  W = 0x3456;
@@ -903,7 +910,12 @@ printf(" Read memory Hi Endian QWORD:\t%.3f[ns]\tunalligned %.3f[ns]\n", 1000*f/
 #endif
 
 
-TempF=fopen(TEMP_FILE,"wb");
+TempF = fopen(TEMP_FILE,"wb");
+if(TempF==NULL)
+  {
+  printf("\nCannot open file \"%s\" for writing!", TEMP_FILE);
+  return;
+  }
 for(i=0; i<16384; i++)
     fputc(i,TempF);
 fflush(TempF);
