@@ -1,5 +1,5 @@
 /****************************************************
-* unit:    strings           release 0.27           *
+* unit:    strings           release 0.29           *
 * purpose: general manipulation with text strings   *
 * Licency: GPL or LGPL                              *
 * Copyright: (c) 1998-2025 Jaroslav Fojtik          *
@@ -8,9 +8,6 @@
 #include <stdio.h>
 #include <string.h>
 #include <ctype.h>
-#ifdef Streams
- #include <iostream.h>
-#endif
 
 #include "stringa.h"
 
@@ -489,9 +486,9 @@ if(str!=NULL)
   unsigned StrSize=strlen(str);
   if(StrSize>0)
     {
-    long NewSize=s1.size+StrSize;
+    unsigned NewSize = s1.size + StrSize;
     s1.resize(NewSize);
-    if(s1.ch==NULL || (long)s1.maxlen<NewSize)
+    if(s1.ch==NULL || s1.maxlen<NewSize)
 	{
 	RaiseError(StringsId|IntOverflow,&s1);	//Size overflow
 	return(s1);	//overflow!!!
@@ -813,10 +810,10 @@ return(temp_string(tmp));
 
 temp_string insert(const string &s, const string &s2, int position)
 {
- if((position>length(s))||(position<0))
-	{
-	return temp_string();
-	}
+ if((unsigned)position>length(s) || position<0)
+ {
+   return temp_string();
+ }
  if(length(s)==0) return(temp_string(s2.ch,s2.size));
  if(length(s2)==0) return(temp_string(s.ch,s.size));
 
@@ -864,10 +861,10 @@ temp_string replacesubstring(const string & s, const char *substring, const char
 {
 char *newptr,*ptr;
 char c;
-int substrlen;
+unsigned substrlen;
 
  if(substring==NULL) return(temp_string(s.ch,s.size));
- substrlen=strlen(substring);
+ substrlen = strlen(substring);
  if(substrlen==0 || length(s)<substrlen) return(temp_string(s.ch,s.size));
 
  ptr = s();
@@ -884,7 +881,7 @@ int substrlen;
     tmp+=newsubstring;
 
     *newptr=c;
-    ptr=newptr+substrlen;
+    ptr = newptr+substrlen;
     } while((newptr=StrStr(ptr,substring)) != NULL);
  tmp += ptr;
 
@@ -1014,7 +1011,12 @@ int string::cat_printf(const char* format, ...)
 
 
 #ifdef Streams
+
+#ifdef IOSTREAM_H_ONLY
 ostream &operator<<(ostream & xout, const string &s)
+#else
+std::ostream &operator<<(std::ostream & xout, const string &s)
+#endif
 {
  return xout<<s();
 }
