@@ -299,7 +299,7 @@ unsigned TablePosStart;
 
  F = fopen(Switch,"wb");
  fprintf(F,
-    "/*Do not edit this file. It is automatically generated.*/\n"
+    "/*Do not edit this file. It is automatically generated in %s.*/\n"
     "\n"
     "#ifdef __Limited_Proc_Size\n"
     " char *BorlandCPPIsShit(uint16_t wchar, TconvertedPass1 *cq);\n"
@@ -348,7 +348,7 @@ unsigned TablePosStart;
     "	}\n"
     "\n"
     "switch(wchar_code) {\n"
-    "\n", TablePosStart, TablePosStart, j);
+    "\n", __DATE__, TablePosStart, TablePosStart, j);
 
  Fcp = fopen(Table,"wb");
  j = 0;
@@ -534,7 +534,7 @@ doublelist llHTML;
 string FileName;
 int TimeoutCounter;
 
- puts("<<<cplib>>> (c)1999-2023 J.Fojtik");
+ puts("<<<cplib>>> (c)1999-2025 J.Fojtik");
 
  if(argc>1)
    {
@@ -684,7 +684,7 @@ WriteTranslator(cp1250,cpkam,trn,F);
    printf("Cannot write to the file \"%s\"", FileName());
    return -3;
  }
- fprintf(F,"/*Do not edit this file. It is automatically generated.*/\n");
+ fprintf(F,"/*Do not edit this file. It is automatically generated in %s.*/\n", __DATE__);
  BuildTranslator(cphtml,internal,F);
  WriteStringTable(F,cphtml,llHTML);
  cphtml.Erase();
@@ -697,7 +697,7 @@ WriteTranslator(cp1250,cpkam,trn,F);
    printf("Cannot write to the file \"%s\"", FileName());
    return -2;
  }
- fprintf(F,"/*Do not edit this file. It is automatically generated.*/\n");
+ fprintf(F,"/*Do not edit this file. It is automatically generated in %s.*/\n", __DATE__);
  BuildTranslator(cpkam,internal,F);		cpkam.Erase();
  fprintf(F,"WCpTranslator cp895internal(\"cp895TOinternal\",255,kam_internal);\n\n");	// alias
 
@@ -751,7 +751,7 @@ WriteTranslator(cp1250,cpkam,trn,F);
    goto SkipMtef;
  }
 
- fprintf(F,"/*Do not edit this file. It is automatically generated.*/\n");
+ fprintf(F,"/*Do not edit this file. It is automatically generated in %s.*/\n", __DATE__);
  BuildTranslator(symbol, internal, F);		symbol.Erase();
  BuildTranslator(Wingdings, internal, F);	Wingdings.Erase();
  BuildTranslator(mtef2, internal, F);		mtef2.Erase();
@@ -766,7 +766,7 @@ SkipMtef:
    printf("Cannot write to the file \"%s\"", FileName());
    return -3;
  }
- fprintf(F,"/*Do not edit this file. It is automatically generated.*/\n");
+ fprintf(F,"/*Do not edit this file. It is automatically generated in %s.*/\n", __DATE__);
  BuildTranslator(MAC_ROMAN,internal,F);		MAC_ROMAN.Erase();
  if(FcloseEpilog(F,FileName(),"macroman.trn")) return -1;
 
