@@ -72,7 +72,7 @@ PropertyList::~PropertyList()
 {
   if(pProperties != NULL)
   {
-    for(int i=0; i<PropCount; i++)
+    for(unsigned i=0; i<PropCount; i++)
     {
       if(pProperties[i] != NULL)
       {
@@ -88,7 +88,6 @@ PropertyList::~PropertyList()
 
 void PropertyList::AddProp(PropertyItem *NewProp)
 {
-int i;
   if(NewProp==NULL) return;
 	// Method 1: list ie empty.
   if(pProperties == NULL)
@@ -104,7 +103,7 @@ int i;
     return;
   }
 	// Method 2: list has a free slot.
-  for(i=0; i<PropCount; i++)
+  for(unsigned i=0; i<PropCount; i++)
   {
     if(pProperties[i]==NULL)
     {
@@ -188,8 +187,8 @@ Image::Image(const Image & I, bool AllFrames)
 
  if(!I.Properties.isEmpty())
  {
-    for(int i=0; i<I.Properties.PropCount; i++)
-      Properties.AddProp(I.Properties.pProperties[i]);
+   for(unsigned i=0; i<I.Properties.PropCount; i++)
+       Properties.AddProp(I.Properties.pProperties[i]);
  }
 
  x=I.x; y=I.y; dx=I.dx; dy=I.dy; RotAngle=I.RotAngle;
