@@ -17,8 +17,8 @@
 
 #define LineLength   80		/* Split lines after more than LineLength charcters */
 
-#define VersionWP2L	"4.14"
-#define VersionDate	"1 Mar 2025"  /* day (space) month (space) full year */
+#define VersionWP2L	"4.16"
+#define VersionDate	"16 Jul 2025"  /* day (space) month (space) full year */
 
 
 /** Constants for a flag InputPS */
@@ -107,6 +107,7 @@ void LoadConfigFile(const char *filename);
 int CheckFileFormat(FILE *wpd,FFormatDetect & FilForD);
 
 /* Variables for Convert_first_pass: */
+
 typedef enum
 {
     NormalText =  0,
@@ -241,7 +242,7 @@ public:
   unsigned char flag;
   short int FirstSection;
   signed char recursion;
-  char ObjType[48];
+  char ObjType[64];
 
   FILE *wpd, *table, *strip, *log, *err;
   const CpTranslator *ConvertCpg;
@@ -577,6 +578,7 @@ typedef enum
 
 typedef enum
 {
+  STYLE_DISABLED = -1,
   STYLE_NOTUSED = 0,
   STYLE_USED = 1
 } TStyle;
